import time
from module.main import Normalizer

if __name__ == "__main__":

    # # Testing Date format
    # date_list = [
    #     "০১-এপ্রিল/২০২৩",
    #     "সেপ্টেম্বর ০৫ ২০২৩",
    #     "01-Apr/2023" "এপ্রিল ২০২৩" "2023-04-05",
    #     "06-04-2023",
    #     "04/01/2023",
    #     "07 April, 2023",
    #     "Apr 1, 2023",
    #     "2023/04/01",
    #     "01-Apr-2023",
    #     "01-apr/2023",
    # ]
    # # # # number = "123456" or "২০২৩"
    # # number = "২০২৩"
    nrml = Normalizer()
    # # # # # print("++++++++++++++++++++ Date testing ++++++++++++++++++++++")
    # # # # print("Date format Testing : ", end ="", flush=True)
    # for date_ in date_list:
    #     start_time = time.time()
    #     print("date_:", date_)
    #     formated_date = nrml.date_format(date_, language="en")
    #     print(formated_date)
    # # print("++++++++++++++++++++ end of Date testing ++++++++++++++++++++++")

    # # print("++++++++++++++++++++ en number to bn number convert ++++++++++++++++++++++")
    # number = "1234"
    # number = nrml.number_convert(number, language="en")

    # number = nrml.number_convert(number, language="bn")

    # print("Bn Number : ", number)
    # print("++++++++++++++++++++ stop number convert ++++++++++++++++++++++")

    # # print("++++++++++++++++ Today +++++++++++++++++++++")
    # today_date = nrml.today(language="bn")
    # # today_date = nrml.today(language="en")
    # print(today_date)

    # # print("++++++++++++++++ End Today +++++++++++++++++++++")
    # # # print(today_date)
    # # print("++++++++++++++++ weekdays +++++++++++++++++++++")
    # weekdays = nrml.weekdays()
    # weekdays = nrml.weekdays(language="bn")
    # weekdays = nrml.weekdays(language="en")
    # weekdays = nrml.weekdays(day = "সোমবার")
    # weekdays = nrml.weekdays(day = "Monday")
    # print(weekdays)

    # # print("++++++++++++++++ end weekdays +++++++++++++++++++++")
    # # # print(weekdays)
    # # print("+++++++++++++++ seasons ++++++++++++++++++++++++")
    # seasons = nrml.seasons()
    # seasons = nrml.seasons(language="bn")
    # seasons = nrml.seasons(language="en")
    # seasons = nrml.seasons(seasons = "গ্রীষ্ম")
    # print(seasons)

    # # print("+++++++++++++++ end seasons ++++++++++++++++++++++++")

    # # print("+++++++++++++++++ months +++++++++++++++++++++++++++")
    # month = nrml.months()
    # month = nrml.months(month="মার্চ")
    # print(month)

    # text = "রাহিম ক্লাস ওয়ান এ ১ম, ১১তম ২২ তম ৩৩ তম, ১২৩৪ শতাব্দীতে ¥২০৩০.১২৩৪ বিবিধ  বাকেরগঞ্জ উপজেলার প্রায় 40 ভাগের পেশাই চাষাবাদ 80 and 40 ২২"

    # text = nrml.text_normalizer(text)

    # print(text)

    # input_texts = [
    #     "আমি এক দুই তিন চার পাঁচ টু থ্রি ফাইভ ছয় সেভেন এইট নাইন শূন্য আমার ফোন নাম্বার জিরো ওয়ান ডাবল সেভেন",
    #     "ওয়ান ডাবল নাইন টু",
    #     "একশ বিশ টাকা",
    #     "জিরো টু ডাবল ওয়ান",
    #     "জিরো ওয়ান ডাবল সেভেন থ্রি ডাবল ফাইভ নাইন থ্রি সেভেন নাইন",
    #     "আমার ফোন নম্বর জিরো ওয়ান ডাবল সেভেন থ্রি ডাবল ফাইভ নাইন থ্রি সেভেন নাইন",
    #     "ট্রিপল টু ওয়ান",
    #     "দুই হাজার চারশো বিশ",
    #     "দুই হাজার চারশ  বিশ",
    #     "হাজার বিশ",
    #     "ডাবল নাইন টু",
    #     "এক লক্ষ চার হাজার দুইশ",
    #     "এক লক্ষ চার হাজার দুইশ এক",
    #     "এক লক্ষ চার হাজার দুইশ এক টাকা এক দুই",
    #     "আমাকে এক লক্ষ দুই হাজার টাকা দেয়",
    #     "আমাকে এক লক্ষ দুই হাজার এক টাকা দেয় এন্ড তুমি বিশ হাজার টাকা নিও এন্ড এক লক্ষ চার হাজার দুইশ এক টাকা এক ডবল দুই",
    #     "ছয় হাজার বিশ",
    #     "আমার সাড়ে পাঁচ হাজার",
    #     "আমার সাড়ে তিনশ",
    #     "আড়াই হাজার",
    #     "আড়াই লক্ষ",
    #     "ডেরশ",
    #     "আমাকে ডেরশ টাকা দেয়",
    #     "সাড়ে পাঁচ কোটি টাকা",
    #     "সাড়ে 1254 টাকা",
    #     "জিরো",
    #     "একশ বিশ take একশ",
    #     "জিরো টু ডাবল ওয়ান",
    #     "জিরো টু ওয়ান ওয়ান",
    #     "থ্রি ফোর ফাইভ এইট",
    #     "একশ বিশ টাকা",
    #     "ডাবল ওয়ান ডবল টু",
    #     "জিরো ওয়ান টু",
    #     "থ্রি ফোর ফাইভ সিক্স",
    #     "সেভেন এইট নাইন টেন",
    #     "একশ দুইশ তিনশ",
    #     "চারশ পাঁচশ",
    #     "ছয়শ সাতশ",
    #     "আটশ নয়শ",
    #     "দশ তিরানব্বই",
    #     "ট্রিপল থ্রি টু",
    #     "শূন্য এক দুই তিন",
    #     "চার পাঁচ ছয় সাত",
    #     "আট নয় দশ এগারো",
    #     "বারো তেরো চৌদ্দ পনেরো",
    #     "ষোল সতেরো আঠারো উনিশ",
    #     "বিশ একুশ বাইশ তেইশ",
    #     "চব্বিশ পঁচিশ ছাব্বিশ সাতাশ",
    #     "আঠাশ ঊনত্রিশ ত্রিশ একত্রিশ",
    #     "বত্রিশ তেত্রিশ চৌত্রিশ পঁয়ত্রিশ",
    #     "ছত্রিশ সাঁইত্রিশ আটত্রিশ ঊনচল্লিশ",
    #     "চল্লিশ একচল্লিশ বিয়াল্লিশ তেতাল্লিশ",
    #     "চুয়াল্লিশ পঁয়তাল্লিশ ছেচল্লিশ সাতচল্লিশ",
    #     "আটচল্লিশ ঊনপঞ্চাশ পঞ্চাশ একান্ন",
    #     "বাহান্ন তিপ্পান্ন চুয়ান্ন পঞ্চান্ন",
    #     "ছাপ্পান্ন সাতান্ন আটান্ন ঊনষাট",
    #     "ষাট একষট্টি বাষট্টি তেষট্টি",
    #     "চৌষট্টি পঁয়ষট্টি ছেষট্টি সাতষট্টি",
    #     "আটষট্টি ঊনসত্তর সত্তর একাত্তর",
    #     "বাহাত্তর তিয়াত্তর চুয়াত্তর পঁচাত্তর",
    #     "ছিয়াত্তর সাতাত্তর আটাত্তর ঊনআশি",
    #     "আশি একাশি বিরাশি তিরাশি",
    #     "চুরাশি পঁচাশি ছিয়াশি সাতাশি",
    #     "আটাশি ঊননব্বই নব্বই একানব্বই",
    #     "বিরানব্বই তিরানব্বই চুরানব্বই পঁচানব্বই",
    #     "ছিয়ানব্বই সাতানব্বই আটানব্বই নিরানব্বই",
    #     "এক লক্ষ চার হাজার দুইশ এক টাকা এক দুই",
    #     "তিনশ পঁচিশ পাঁচশ",
    #     "তিনশ পঁচিশ পাঁচশ এক",
    #     "চা-পুন",
    #     "ওকে",
    #     "ডের আউটস্ট্যান্ডিং কত",
    #     "ডাবল",
    #     "নাইন ডাবল এইট",
    #     "দশ বারো এ এগুলা একশ একশ দুই",
    #     "এক লক্ষ তেত্রিশ চার",
    #     "আমাকে এক লক্ষ দুই হাজার এক টাকা দেয় এন্ড তুমি বিশ হাজার টাকা নিও এন্ড এক লক্ষ চার হাজার দুইশ এক টাকা এক ডবল দুই"
    #     ]
    # for i in input_texts:
    #     print("="*40)
    #     print("input : ", i)
    #     text = nrml.word2number(i)
    #     print("output : ", text)
    #     print("="*40)
    # text = "সম্মেলনটি সেপ্টেম্বর ০৫ ২০২৩ তারিখে নির্ধারিত করা হয়েছে. এপ্রিল ২,০২৩"
    # formated_date = nrml.date_extraction(text)

    # print(formated_date)

    # # text = "৫ বছরে নন-ক্যাডার পদে ৭,৪৪৭ জনকে নিয়োগের সুপারিশ করা হয়েছে 1,230"
    # text = "৫ বছরে নন-ক্যাডার পদে ৭,৪৪৭ জনকে নিয়োগের সুপারিশ করা হয়েছে"

    # text = "শীঘ্রই ভিক্টোরিয়ার এক প্রতিনিধিদল আসছেন,শিলংয়ের ব্রুকসাইড হাউসে"

    # text = "The numbers are 10 নন-ক্যাডার 20.5  30, and 40.75. সুপারিশ ২০৩০.৩০ 12 23 45"

    bangla_sentences = [
        # "The numbers are 10 নন-ক্যাডার 20.5  30, and 40.75. সুপারিশ ২০৩০.৩০ 12 23 45",
        # "১৯৯৬ সালের ৬ তারিখে নির্ধারিত করা হয়েছে.",
        # "১৯৯৬ সালের ৬ সেপ্টেম্বর ভ্রমণ পরিকল্পনা করছি.",
        # "আমি জুলাই ২০২৩ তে একটি সমুদ্র ভ্রমণ পরিকল্পনা করছি.",
        # "সম্মেলনটি সেপ্টেম্বর ০৫ ১৯৯৬ তারিখে নির্ধারিত করা হয়েছে.",
        # "আমরা খ্রীষ্টমাসের জন্য ডিসেম্বর ২৫ ২০২৩ তারিখে পরিবারের সংগঠন করব.",
        # "আমার বোনের বিয়ে ১৮ মার্চ, ২০২৩ তারিখে.",
        # "আমি আগামী ১২ আগস্ট, ২০২৩ তারিখে আমার জন্মদিনে দেখা করছি.",
        # "আমরা ফেব্রুয়ারি ২০২৩ তে স্কিউইং যাব.",
        # "আমাদের কোম্পানির পিকনিকটি জুন ৩০ ২০২৩ তারিখে নির্ধারিত হয়েছে.",
        # "আমার গুরুত্বপূর্ণ পরীক্ষা ১০ মে, ২০২৩ তারিখে.",
        # "নতুন সেমিস্টার শুরু হয় জানুয়ারি ২০২৩ তারিখে.",
        # "আমরা এপ্রিল ২০২৩ তে একটি রোড ট্রিপ পরিকল্পনা করছি.",
        # "আমি অক্টোবর ২০২৩ তারিখে একটি নতুন অ্যাপার্টমেন্টে যাচ্ছি.",
        # "আপনার ক্যালেন্ডারের মার্ক নভেম্বর ০৫, 1996, এটি দীপাবলি.",
        # "আমি জুলাই 1996 তারিখে গরম শিবিরের জন্য উৎসাহিত.",
        # "মার্চ ২৫, 1195 তারিখের ২৫টি কনসার্ট টিকেটগুলি দ্রুত বিক্রয় হচ্ছে.",
        # "আগস্ট ২০২৩ তারিখে একটি বারবিকিউ পার্টি আয়োজন করা হবে.",
        # "আমি মে ২০২৩ তারিখে আমার নানা-নানির কাছে যাচ্ছি.",
        # "আমি সেপ্টেম্বর ২০২৩ তারিখে একটি বিয়ে অনুষ্ঠানে যাচ্ছি.",
        # "আমরা জুন ২০২৩ তে ইউরোপে একটি ভ্রমণ পরিকল্পনা করছি.",
        # "আমার ডেন্টিস্টের অ্যাপয়েন্টমেন্ট এপ্রিল ১০, ১৯৯৬",
        # "কোম্পানির বার্ষিক সভা ফেব্রুয়ারি ২০২৩ তারিখে হয়.",
        # "আমার অনুষ্ঠান সমাপন হয়েছে জুন ১৫, ২০২৩ তারিখে.",
        # "আমি মার্চ ২০২৩ তারিখে একটি নতুন চাকরি শুরু করছি.",
        # "আমি মে ২০২৩ তারিখে পাহাড়ে ট্রেকিং করতে যাচ্ছি.",
        # "বিদ্যালয়ের নাটকটি নভেম্বর ২০২৩ তারিখে নির্ধারিত হয়েছে.",
        # "আমরা অক্টোবর ২০২৩ তার",
        # "১৯৯৬ সালের ৬ সেপ্টেম্বর",
        # "২০৩০ সালের ৬ সেপ্টেম্বর",
        # "১৯৯৬ সালের৬ তারিখে নির্ধারিত করা হয়েছে.",
        # "১৯৯৬সালের ৬ সেপ্টেম্বররণ ভ্রমণ পরিকল্পনা করছি ২০৩০সালের ৬সেপ্টেম্বর",
        # "এয়ারলাইনসসহ তিনটি এয়ারলাইনসের ৫১টি ফ্লাইটে মো: ২০ হাজার ২৯১ জন হজযাত্রী সৌদি আরবে গেছেন। ",
        # "এ বছর হজ করতে ৮৫ হাজার ২৫৭ জনের সৌদি আরবে যাওয়ার কথা রয়েছে।",
        # " সাঃ কিমি হাফিক বিডিটি এয়ারলাইনসসহ তিনটি এয়ারলাইনসের ৫১টি কিমি. ফ্লাইটে মোট ২০ হাজার ২৯১ জন হজযাত্রী সৌদি আরবে গেছেন।",
        # "এ বছর হজ করতে ৮৫ হাজার ২৫৭ জনের সৌদি আরবে যাওয়ার কথা রয়েছে। ৫ম",
        # "প্রদর্শনীটি চলার কথা ছিল ১২ মে পর্যন্ত, তবে দর্শকদের ব্যাপক আগ্রহের কারণে তিন দিন সময় বাড়িয়ে ১৫ মে পর্যন্ত করা হয়েছিল ১৫.১৫",
        # "The numbers are 10 নন-ক্যাডার 20.5  30, and 40.75. সুপারিশ ২০৩০.৩০ 12 23 45",
        # "[১৯৯৬]-সালের-৬:তারিখে-নির্ধারিত করা হয়েছে",

        # "[১৯৯৬]-সালের-৬:তারিখে-নির্ধারিত করা হয়েছে.",
        # "১৯৯৬সালের ৬ সেপ্টেম্বররণ ভ্রমণ পরিকল্পনা করছি ২০৩০সালের ৬সেপ্টেম্বর",
        # "আজকের তাপমাত্রা ৪৪°F",
        # "আজকের তাপমাত্রা ৪৪°C",
        # "যেমন ১৯৬১ সালে দেশটির তৎকালীন প্রেসিডেন্ট ডোয়াইট ডি আইজেনহাওয়ার শিক্ষা খাতে সামরিক শিল্পের প্রবেশের বিপদ নিয়ে সতর্ক করেছিলেন।",
        # "১৯৯৬সালের ৬ সেপ্টেম্বররণ ভ্রমণ পরিকল্পনা করছি ২০৩০সালের ৬সেপ্টেম্বর",
        # "উদাহরণস্বরূপ, আপনার মোটরযানের রেজিস্ট্রেশন নাম্বার ঢাকা মেট্রো-গ-12-1212 এবং টাকা জমা রশিদের ট্রানজেকশন নাম্বার 2001011325989",
        # "[১৯৯৬]-সালের-৬:তারিখে- ১৯৯৬—৯৯ নির্ধারিত করা হয়েছে. ১৯৯৬-৯৯",
        # "১৯৮৭-র ১৯৯৫ সালে",
        # "দয়া !@করে #পবিত্র &)কুরআনুল *কারিম বলেন,,,,পবিত্র কথাটা অবশ্যই বলবেন,,, প্লিজ",
        # "১৯৯৬সালের ৬ সেপ্টেম্বররণ ভ্রমণ পরিকল্পনা ৬ সেপ্টেম্বর করছি ২০৩০সালের ২সেপ্টেম্বর",
        # " দুর্নীতির মাধ্যমে অর্জিত আয়ের উৎস গোপনের জন্য নিজের নামসহ তাঁর আত্মীয়স্বজনের নামে ৭০০০টির বেশি হিসাব খোলেন।"
        # "১৯৯৬ সালের নির্ধারিত করা হয়েছে. ১৯৯৬-৯৬",
        # "১৯৯৬সালের ৬ সেপ্টেম্বররণ ভ্রমণ পরিকল্পনা করছি ২০৩০সালের ৬সেপ্টেম্বর দুর্নীতির মাধ্যমে অর্জিত আয়ের উৎস গোপনের জন্য নিজের নামসহ ",
        # "তাঁর আত্মীয়স্বজনের নামে ৭০০০টির বেশি হিসাব খোলেন।",
        # "আজকের তাপমাত্রা৪৪°F",
        # "আজকের তাপমাত্রা ৪৪°C",
        # "যেমন ১৯৬১ সালে দেশটির তৎকালীন প্রেসিডেন্ট ডোয়াইট ডি আইজেনহাওয়ার শিক্ষা খাতে সামরিক শিল্পের প্রবেশের বিপদ নিয়ে সতর্ক করেছিলেন।",
        # "১৯৯৬সালের ৬ সেপ্টেম্বররণ ভ্রমণ পরিকল্পনা করছি ২০৩০সালের ৬সেপ্টেম্বর",
        # " বাংলাদেশের পাসপোর্টের অভ্যন্তরে ইস্যু করানোর সময়ে নিয়মিত, জরুরী, এবং অতীব জরুরী বিতরণের ফি নিম্নলিখিত: নিয়মিত বিতরণ (48 পৃষ্ঠা এবং 10 বছর মেয়াদ) ",
        # "পাসপোর্ট ফি: ৪,০২৫ টাকা জরুরী বিতরণ (48 পৃষ্ঠা এবং 10 বছর মেয়াদ) পাসপোর্ট ফি: ৬,৩২৫ টাকা অতীব জরুরী বিতরণ (48 পৃষ্ঠা এবং 10 বছর মেয়াদ) ",
        # "পাসপোর্ট ফি: ৮,৬২৫ টাকা নিয়মিত বিতরণ (64 পৃষ্ঠা এবং 5 বছর মেয়াদ) পাসপোর্ট ফি: ৫,৭৫০ টাকা জরুরী বিতরণ (64 পৃষ্ঠা এবং 5 বছর মেয়াদ) ",
        # "পাসপোর্ট ফি: ৮,০৫০ টাকা অতীব জরুরী বিতরণ (64 পৃষ্ঠা এবং 5 বছর মেয়াদ) পাসপোর্ট ফি: ১০,৩৫০ টাকা",
        # "বাংলাদেশের পাসপোর্টের অভ্যন্তরে ইস্যু করানোর সময় 10/12/1956",
        # "৬/৯/১৯৯৬ বাংলাদেশের পাসপোর্টের অভ্যন্তরে ইস্যু করানোর সময় 10/12/24",
        # "ডিজিটাল রেজিস্ট্রেশন সার্টিফিকেট সংক্রান্ত যোগাযোগ করতে হলে 01790-111111 অথবা 01790-540210 নম্বরে যোগাযোগ করতে হবে +8801790540211",
        # "ডিজিটাল রেজিস্ট্রেশন সার্টিফিকেট সংক্রান্ত যোগাযোগ করতে হলে ০১৭৯০-১১১১১১ অথবা ০১৭৯০-৫৪০২১০ নম্বরে যোগাযোগ করতে হবে ০১৭৯০৫৪০২১১",
        # "রাহিম ক্লাস ওয়ান এ ১ম, ১১তম ২২ তম ৩৩ তম, ১২৩৪ শতাব্দীতে ¥২০৩০.১২৩৪ বিবিধ  বাকেরগঞ্জ উপজেলার প্রায় 40 ভাগের পেশাই চাষাবাদ 80 and 40 ২২"
        # "অর্থাৎ, আবেদনকারীর বয়স ১ বছর হলে জন্ম নিবন্ধন ফি ১০ টাকা, বয়স ২ বছর হলে ২০ টাকা, বয়স ৫ বছর হলে ৫০ টাকা, এবং বয়স ১০ বছর হলে ১০০ টাকা হবে",
        # "বাংলাদেশের পাসপোর্টের ৪৮ পৃষ্ঠা এবং ১০ বছর মেয়াদের সহ পাসপোর্টের জন্য নিয়মিত বিতরণে ফি ৫,৭৫০ টাকা, জরুরী বিতরণে ফি ৮,০৫০ টাকা, এবং অতীব জরুরী ",
        # "বিতরণের ফি ১০,৩৫০ টাকা",
        # "১৯৯৬ টাকা বাংলাদেশের পাসপোর্টের ৬৪ পৃষ্ঠা এবং ৫ বছর মেয়াদের সহ পাসপোর্টের জন্য নিয়মিত বিতরণে ফি ৬,৩২৫ টাকা",
        # "জরুরী বিতরণে ফি ৮,৬২৫.৬২৫ টাকা, এবং অতীব জরুরী বিতরণের ফি ১২,০৭৫ টাকা1234 হতে  ২০১৪ সালে বাংলাদেশ আর মানুষ বুজতে শুরু করে", 
        # "1995 সাল  ,  কালো রাত। বুধবার থেকে দুটি আবাসিক এলাকার ৯টি ব্লকে ৯টি দল পাহারা দিচ্ছে। মোসা. রশিদের "
        # "১৯৫৪ সালের রাহিম ক্লাস ওয়ান এ ১ম, এন্ড বাসার ক্লাস এ ৩৩ তম, সে জন্য ২০৩০ শতাব্দীতে ¥২০৩০.১২৩৪ দিতে হয়েছে",
        # "উদাহরণস্বরূপ, আপনার মোটরযানের রেজিস্ট্রেশন নাম্বার ঢাকা মেট্রো-গ-12-1212 এবং টাকা জমা রশিদের ট্রানজেকশন নাম্বার 2001011325989",
        # "Examples: 2024-05, 1254, 1195–05, 1995—05, 2024―05, 01775-937895"
        # """আমি যে যে সার্ভিস দিয়ে থাকি 
        # ১.০ মুড়ি বিক্রি 
        # ২. চাল
        # ৩. ডাল 
        # 4.1 ডাল""",
        # "১৯৫৪ থেকে ২০১৪ সালে বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "1944 থেকে 2010 সালে বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "২০২৩ হতে  ২০১৪ সালে বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "১৯৫৪ থেকে ২০১৪ সালে বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "1234 হতে  ২০১৪ শতাব্দী বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "২০২৩ চেয়ে  ২০১৪ সালের বাংলাদেশ আর মানুষ বুজতে শুরু ক",
        # "1995 থেকে 2014 শতাব্দীর বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "1234 হতে  ২০১৪ সালে বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "2023 চেয়ে 2014সালে বাংলাদেশ আর মানুষ বুজতে শুরু ক",
        # "১৯৫৪ থেকে ২০১৪ সালে বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "1234 হতে  ২০১৪ শতাব্দীর বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "২০২৩ চেয়ে  ২০১৪ সালের বাংলাদেশ আর মানুষ বুজতে শুরু ক",
        # "1995 থেকে 2014 শতাব্দীর বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "1234 হতে  ২০১৪ শতাব্দীতে বাংলাদেশ আর মানুষ বুজতে শুরু করে",
        # "2023 চেয়ে 2014সাল বাংলাদেশ আর মানুষ বুজতে শুরু ক",
        # "2023 চেয়ে 2014 খ্রিস্টাব্দ বাংলাদেশ আর মানুষ বুজতে শুরু ক",
        # "2023 চেয়ে 2014 খ্রিস্টাব্দের বাংলাদেশ আর মানুষ বুজতে শুরু ক",
        # "2023 চেয়ে 2014 খ্রিস্টাব্দ বাংলাদেশ আর মানুষ বুজতে শুরু ক",
        # "2023 চেয়ে 2014 খ্রিস্টপূর্বাব্দের বাংলাদেশ আর মানুষ বুজতে শুরু ক",
        # "2023 চেয়ে 1115 বাংলাদেশ আর মানুষ বুজতে শুরু ক ২০২৩ চেয়ে  ২০১৪ সালে আর মানুষ বুজতে শুরু ২০২৩ চেয়ে 2025 সালে",
        # "২০১২সাল", 
        # "1994সাল",
        # "09612345678ডিজিটাল  1 6 2 2 2 রেজিস্ট্রেশন০৯৬১২৩৪৫৬৭৮, ডিজিটাল রেজিস্ট্রেশন ০৯৬১০-০১০৬১৬ 09610-010616 সার্টিফিকেট সংক্রান্ত",
        #  " 01790540211124562 যোগাযোগ করতে হলে01790-540211অথবা 01790-541111 নম্বরে যোগাযোগ করতে হবে 01790540211, +8801790540211, ০১৭৯০৫৪০২১১, +৮৮০১৭৯০৫৪০২১১",
        # "যোগাযোগ করতে হলে01790540211অথবা",
        # "যোগাযোগ করতে হলে01790-540211অথবা",
        # " জরুরী বিতরণে ফি ৮,৬২৫.৬২৫ টাকা",
        # "দাঃবাঃ আমাদের প্রধান অতিথি",
        # "মোসা: রুবিনা ভালো রান্না করেন",
        # "রাশিয়ায় ₽৭০০ ব্যয় করেছি",
        # "আমার কাছে £৫০০ এবং €৩০০ আছে",
        # "আমি ৳১০,০০০ ব্যয় করেছি"
        # "আ: রহমান আমাদের বন্ধু",
        # "মোসাঃ রুবিনা ভালো রান্না করেন",
        # "শাইখ দাঃবাঃ আমাদের মসজিদে আসবেন",
        # "আমার দাদা মোসাঃ খাতুন খুব ভালো মানুষ ছিলেন",
        # "দাঃবাঃ আমাদের প্রধান অতিথি",
        # "আ: রহমান আমাদের বন্ধু",
        # "মো: রিয়াদ ভালো ছাত্র",
        # "আজকের তাপমাত্রা ৪৪°F",
        # "আজকের তাপমাত্রা৪৪°F",
        # "মো: কাশেম একজন সফল ব্যবসায়ী",
        # "তিনি পঞ্চাশ পারসেন্ট ছাড় পাচ্ছেন আজকের অফারে।"

        # "আমার কাছে £৫০০ এবং €৩০০ আছে",
        # "এই বিলটি ₽৫০০০ এর",
        # "এই বিলটি ₽5000 এর",
        # "রাশিয়ায় ₽৭০০ ব্যয় করেছি",
        # "রাশিয়ায় ₽5000 ব্যয় করেছি"
        # "এই পণ্যটির মূল্য $25.50 লাখ",
        # "আমার কাছে ৳৫০০ আছে",
        # "সে £১০০ ধার নিয়েছে",
        # "রাশিয়ায় ₽৭০০ ব্যয় করেছি",
        # "তুরস্কে ₺৩০০ দিয়ে কেনাকাটা করলাম",
        # "আমি ৳১০,০০০ ব্যয় করেছি",
        # "ব্যাংকে ₹২৫,০০০ জমা দিয়েছি",
        # "তিনি ₹১০ লাখ দান করেছেন",
        # "দোকানে ¥১৫০০ খরচ করলাম",
        # "সে ₺৭৫০ দিয়ে পোশাক কিনেছে",
        # "আমি ৳১০,০০০ ব্যয় করেছি",
        # "১৯৯৬ টাকা বাংলাদেশের পাসপোর্টের ৬৪ পৃষ্ঠা এবং ৫ বছর মেয়াদের সহ পাসপোর্টের জন্য নিয়মিত বিতরণে ফি ৬,৩২৫ টাকা, জরুরী বিতরণে ফি ৮,৬২৫.৬২৫ টাকা, এবং অতীব জরুরী বিতরণের ফি ১২,০৭৫ টাকা",
        # "আমাদের কোম্পানি ৳৫,০০,০০০ বিনিয়োগ করেছে",
        # "আমাদের কোম্পানি ৳৫,০০,০০০ বিনিয়োগ করেছে",
        # "এই বইটির মূল্য $15"
        # "আমার উচ্চতা ১৭০ সেমি",
        # "প্রদর্শনীটি চলার কথা ছিল ১২ মে পর্যন্ত, তবে দর্শকদের ব্যাপক আগ্রহের কারণে তিন দিন সময় বাড়িয়ে ১৫ মে পর্যন্ত করা হয়েছিল ১৫.১৫",
        # "এটা.. খুব.. জরুরি!!"
        # "তারা একসাথে আছে...",
        # "আমি পড়তে ভালোবাসি...",
        # "সেখানে একটি বাড়ি আছে...",
        # "আমি এটা পছন্দ করি না...",
        # "আমি খুব খুশি!!!",
        # "এটি একটি #টেকনোলজি কনফারেন্স।",
        # "দয়া !@করে #পবিত্র &)কুরআনুল *কারিম বলেন,,,,পবিত্র কথাটা অবশ্যই বলবেন,,, প্লিজ",

        # "মার্চ ২৫, 1996 তারিখের কনসার্ট টিকেটগুলি দ্রুত বিক্রয় হচ্ছে",
        # "মার্চ ২৫% তারিখের কনসার্ট টিকেটগুলি দ্রুত বিক্রয় হচ্ছে",
        # "র‍্যাব",
        # "বাংলা​",
        # "র‍্য",
        # "ম‍ধ্য",
        # "রেজিস্ট্রেশন নাম্বার ঢাকা মেট্রো-গ-১৯-৯৯৫৯  চট্টগ্রাম-গ-12-1212 এবং",
        # "তিনি একটি মেল পাঠিয়েছেন @example.com।",
        # "১৯৯৬সালের ৬ সেপ্টেম্বররণ ভ্রমণ পরিকল্পনা করছি ২০৩০সালের ৬সেপ্টেম্বর দুর্নীতির মাধ্যমে অর্জিত আয়ের উৎস গোপনের জন্য নিজের নামসহ তাঁর আত্মীয়স্বজনের নামে ৭০০০টির বেশি হিসাব খোলেন",
        # "১৯৮৭-র ১৯৯৫ সালে",
        # "এয়ারলাইনসসহ তিনটি এয়ারলাইনসের ৫১টি ফ্লাইটে মো: ২০ হাজার ২৯১ জন হজযাত্রী সৌদি আরবে গেছেন। এ বছর হজ করতে ৮৫ হাজার ২৫৭ জনের সৌদি আরবে যাওয়ার কথা রয়েছে",
        # "উদাহরণস্বরূপ, 1969-2024 আপনার মোটরযানের রেজিস্ট্রেশন নাম্বার ঢাকা মেট্রো-গ-12-1212  চট্টগ্রাম-গ-12-1212 এবং টাকা জমা রশিদের ট্রানজেকশন নাম্বার 2001011325989 চট্ট-গ-12-1212",
        "আমার ডেন্টিস্টের অ্যাপয়েন্টমেন্ট ১০ এপ্রিল ১৯৯৬",
        # "যোগাযোগ করতে হলে01790540211অথবা",
        # "নতুন সেমিস্টার শুরু হয় জানুয়ারি ২০২৩ তারিখে.",
        # "মোসা: রুবিনা ভালো রান্না করেন",
        # "মোসা রুবিনা ভালো রান্না করেন",
        # "আমার উচ্চতা ১৭০ সেমি",
        # "1995 সাল  ,  কালো রাত। বুধবার থেকে দুটি আবাসিক এলাকার ৯টি ব্লকে ৯টি দল পাহারা দিচ্ছে। মোসা. রশিদের",
        # "ড. জাকির নায়েক একজন ইসলামিক বক্তা",
        # "NID ড. জাকির নায়েক একজন NID ইসলামিক বক্তা NID.",
        # "NID ড. জাকির নায়েক একজন NIDইসলামিকNID বক্তা NID.",
        # "আমি আমার e-passport পেয়েছি। সে তার e‐passport এর জন্য আবেদন করেছে। তুমি কি e passport তৈরি করেছো? আমার E passport এখনও আসেনি।",
        # "নতুন সেমিস্টার শুরু হয় জানুয়ারি ২০২৩ তারিখে.",
        # "মার্চ ২৫, 1195 তারিখের কনসার্ট টিকেটগুলি দ্রুত বিক্রয় হচ্ছে.",
        # "আপনার এনআইডি ৩২১০৯৮৭৬৫৪৩২।",
        # "এনআইডি নম্বরঃ ১২৩৪৫৬৭৮৯০",
        # "তার NID নম্বর 1234567890123।",
        # "জাতীয় পরিচয়পত্র নং: 987654321098।",
        # "আপনার এনআইডি ৩২১০৯৮৭৬৫৪৩২।",
        # "NID নং: 110022334455",
        # "জাতীয় পরিচয়পত্র নম্বর: 76543210987",
        # "আপনার NID: ৭৬৫৪৩২১০৯৮৭ যাচাই করুন।",
        # "NID Number: 1234567890",
        # " 0987654321 জাতীয় পরিচয় নম্বরঃ 0987654321",
        # "এনআইডি নম্বরঃ 1234567890",
        # "এনআইডি নম্বরঃ ১২৩৪৫৬৭৮৯০",
        # "আমার পাসপোর্ট নম্বর A01234567 এবং তার পাসপোর্ট নম্বর 987654321।",
        # "নতুন ই-পাসপোর্ট নম্বর E12345678 ইস্যু করা হয়েছে।",
        # "তিনি পুরাতন পাসপোর্ট নম্বর 1234567 ব্যবহার করেছেন।",
        # "মেশিন রিডেবল পাসপোর্ট নম্বর B76543210।",
        # "তার পাসপোর্ট নম্বর P87654321 ছিল।",
        # "তার পাসপোর্ট নম্বর P০১২৩৪৫৬৭ ছিল।",
        # "বাংলা নম্বর হিসেবে পাসপোর্ট নম্বর এ০১২৩৪৫৬৭ ও ই১২৩৪৫৬৭৮।",
        # "পাসপোর্ট নম্বর এ০১২৩৪৫৬৭ ও ই১২৩৪৫৬৭৮।",
        # "তার ড্রাইভিং লাইসেন্স নম্বর ঢাকা-12-6789।",
        # "তার ড্রাইভিং লাইসেন্স নম্বর ঢাকা-12-6789।",
        # "আপনি চাইলে আমরা ১ টি ফ্রি কনসালটেশন দিয়ে আপনাকে দেখাতে পারি "
        # "হ্যালো, আমি গত সপ্তাহে আপনাদের ওয়েবসাইট থেকে একটি Samsung Galaxy A27 কিনেছি। আজকে সকাল থেকে ফোনটা অনই হচ্ছে না।"
        # "আপনি ৮/৫ অথবা 8/5 ব্যবহার করতে পারেন মো. মোরিয়াদ এর সাথে যোগাযোগ করতে 01790-540211 নম্বরে।",
        # "দুঃখিত স্যার, ঐ offer-টার validity ছিল গতকাল রাত ১১:৫৯ পর্যন্ত।"
        # "দুঃখিত স্যার, ঐ offer-টার validity ছিল গতকাল রাত 11:59:00 পর্যন্ত।"
        # "2023 চেয়ে 1115 বাংলাদেশ আর মানুষ বুজতে শুরু ক ২০২৩ চেয়ে  ২০১৪ সালে আর মানুষ বুজতে শুরু ২০২৩ চেয়ে 2025 সালে"
        # "যেহেতু হোস্টিংটা it's very close to my heart, আমার first love হচ্ছে হোস্টিং, [laughing]  so I want to be myself।",
        # "Ponds Nourishing Facial Scrub 100 gm - 696473751",
        # "clean & clear face wash 50 ml - 123456789",
        # "আমরা এপ্রিল ২০২৩ তে একটি রোড ট্রিপ পরিকল্পনা করছি."
        # "[১৯৯৬]-সালের-৬:তারিখে-নির্ধারিত করা হয়েছে",
        # "তার ড্রাইভিং লাইসেন্স নম্বর ঢাকা-12-6789।",
        # "তার পাসপোর্ট নম্বর P87654321 ছিল।, 1995-1969 and phone number 01773-550379",
        # "Starlink Standard কিটের জন্য BDT49,500। নির্ভরযোগ্য হাই-স্পিড ইন্টারনেট, যেখানেই যাবেন সেখানেই পাবেন। প্ল্যানের মূল্য শুরু প্রতি মাসে 4,200৳ থেকে।"
        # "উদাহরণস্বরূপ, আপনার মোটরযানের রেজিস্ট্রেশন নাম্বার ঢাকা মেট্রো-গ-12-1212 এবং টাকা জমা রশিদের ট্রানজেকশন নাম্বার 2001011325989"
        # "Orico 2520U3-BK-EP 2.5 inch USB 3.0 Hard Drive Enclosure",
        # "Havit HV-SC055 Laptop Cleaning Kit - HV-SC055",
        # "MSI Thin 15 B13VE Core i5 13th Gen RTX 4050 6GB Graphics 15.6 FHD Gaming Laptop",
        # "MSI Thin A15 B7UC Ryzen 5 7535HS RTX 3050 4GB GDDR6 Graphics 15.6 FHD Gaming Laptop",
        # "Orico 2520U3-BK-EP 2.5 inch USB 3.0 Hard Drive Enclosure",
        # "Orico 123C 2.5 inch USB 3.0 Hard Drive Enclosure 2520U3-BK-EP-346-67895",
        # "Havit HV-SC055 Laptop Cleaning Kit - HV-SC055 and the number is the 12345",
        # "তার ড্রাইভিং লাইসেন্স নম্বর ঢাকা-12-6789।",
        # "তার পাসপোর্ট নম্বর P87654321 ছিল।, 1995-1969 and phone number 01773-550379",
        # "বিল নম্বর  ৪৫৬৭৮০৩৪৫ hello how are you",
        # "গ্রাহকের A/C নং: ৯৮৭৬৫৪৩২১০ এ জমা করুন।",
        # "পেমেন্ট আইডি ১২৩৪৫৬৭৮৯০১২ নিশ্চিত হয়েছে BDT ১০,০০০ এর জন্য।",
        # "Your electricity bill number 202401-123456 is due on 15th January.",
        # "বিল নম্বর  ৪৫৬৭৮০৩৪৫ hello how are you"
        # "01790540211124562 যোগাযোগ করতে হলে01790-540211অথবা 01790-541111 নম্বরে যোগাযোগ করতে হবে",
        # "Awei T71 TWS Earbuds V Bluetooth 5.3 Earphones With Mic",
        # "HTC AT-522 Rechargeable Cordless Trimmer For Men",
        # "Gigabyte A16 GA6H Core i7 13th Gen 16 FHD+ WUXGA Nvidia RTX 5050 Gaming Laptop",
        # "Starlink Standard কিটের জন্য BDT49,500। নির্ভরযোগ্য হাই-স্পিড ইন্টারনেট, যেখানেই যাবেন সেখানেই পাবেন। প্ল্যানের মূল্য শুরু প্রতি মাসে 4,200৳ থেকে।",
        # "১৯৯৬-সালের-৬:তারিখে-নির্ধারিত করা হয়েছে"
        # "গ্রাহকের a/c নং: ৯৮৭৬৫৪৩২১০ এ জমা করুন।"
        # "গ্রাহকের A/C নং: ৯৮৭৬৫৪৩২১০ এ জমা করুন।",
        # "পেমেন্ট আইডি ১২৩৪৫৬৭৮৯০১২ নিশ্চিত হয়েছে BDT ১০,০০০ এর জন্য।",
        # "Your electricity bill number 202401-123456 is due on 15th January.",
        # "বিল নম্বর  ৪৫৬৭৮০৩৪৫ hello how are you"
        # "Your electricity bill number 202401-123456 is due on 15th January.",
        # "পেমেন্ট আইডি ১২৩৪৫৬৭৮৯০১২ নিশ্চিত হয়েছে BDT ১০,০০০ এর জন্য।",
        # "Your electricity bill number 202401-123456 is due on 15th January.",
        # "বিল নম্বর  ৪৫৬৭৮০৩৪৫ hello how are you",
        # "আপনার ভাউচার নম্বর ৩৪৫৬৭৮৯০১২ ৩১ ডিসেম্বর পর্যন্ত বৈধ।",
        #  "আপনার ভাউচার নম্বর ৩৪৫৬৭৮৯০১২ 31 ডিসেম্বর পর্যন্ত বৈধ।",
        # "Contact us at info@example.com or visit https://www.example.com",
        # "Send email to john.doe@company.org and check www.company.org/about",
        # "Multiple contacts: sales@site.com, support@site.co.uk, marketing@site.net",
        # "Visit http://github.com/user/repo or ftp://files.server.com",
        # "My email is test.user+tag@gmail.com and website is example.io",
        # "Check out https://subdomain.example.com:8080/path/to/page?query=1"
        # "my phone number is 01790540211 and phone number 01773-550379",
        # "পাসপোর্ট ফি: ১০,০০০ এর জন্য। B1234567898 টাকা and 10987654321 টাকা and 10987654321 dollar",
        # "সার্টিফিকেট সংক্রান্ত 017907540212424562 যোগাযোগ করতে হলে 01790-540211অথবা 01790-541111 নম্বরে যোগাযোগ করতে হবে 01790540211, +8801790540211, ০১৭৯০৫৪০২১১, +৮৮০১৭৯০৫৪০২১১ we can get 1234567898 টাকা"
        # "09612345678 ডিজিটাল  1 6 2 2 2 রেজিস্ট্রেশন০৯৬১২৩৪৫৬৭৮, ডিজিটাল রেজিস্ট্রেশন ০৯৬১০-০১০৬১৬ 09610-010616 সার্টিফিকেট সংক্রান্ত 01790540211124562 যোগাযোগ করতে হলে01790-540211অথবা 01790-541111 নম্বরে যোগাযোগ করতে হবে 01790540211, +8801790540211, ০১৭৯০৫৪০২১১, +৮৮০১৭৯০৫৪০২১১"
        # "১৯৯৬সালের ৬ সেপ্টেম্বররণ ভ্রমণ পরিকল্পনা করছি ২০৩০সালের ৬সেপ্টেম্বর দুর্নীতির মাধ্যমে অর্জিত আয়ের উৎস গোপনের জন্য নিজের নামসহ তাঁর আত্মীয়স্বজনের নামে ৭০০০টির বেশি হিসাব খোলেন",
        # "Your customer ID 123-456-789-012 is valid."

    #     "পাসপোর্ট নম্বর এ০১২৩৪৫৬৭ ও ই১২৩৪৫৬৭৭।",
    #     "passport number: A12345671 and B98765431",
    #     "ই-পাসপোর্ট: ১২৩৪৫৬৭১২, ৯৮৭৬৫৪৩২১ ও এ৮৭৬৫৪৩২১",
    #     "পাসপোর্ট নং A12345671, B23456781, C34567891",
    #     "passport A12345671 ও passport B98765431",
    # "আমার পাসপোর্ট নম্বর A01234567 এবং তার পাসপোর্ট নম্বর 987654321।",
    # নতুন ই-পাসপোর্ট নম্বর E12345678 ইস্যু করা হয়েছে।
    # তিনি পুরাতন পাসপোর্ট নম্বর 1234567 ব্যবহার করেছেন।
    # মেশিন রিডেবল পাসপোর্ট নম্বর B76543210।
    # তার পাসপোর্ট নম্বর P87654321 ছিল।
    # তার পাসপোর্ট নম্বর P০১২৩৪৫৬৭ ছিল।
    # "বাংলা নম্বর হিসেবে পাসপোর্ট নম্বর এ০১২৩৪৫৬৭ ও ই১২৩৪৫৬৭৮।",
    # পাসপোর্ট নম্বর এ০১২৩৪৫৬৭ ও ই১২৩৪৫৬৭৮।
    # "তার পাসপোর্ট নম্বর P87654321 ছিল।, 1995-1969 and phone number 01773-550379"
    # "আমার জন্ম সাল ১৯৯২",
    # "তার জন্ম ১৯৯২",
    # "জন্ম সাল ১৯৯২ সালে",
    # "সে জন্ম ১৯৯২ সালে",
    # "জন্মসাল ১৯৯২",
    # "জন্ম: ১৯৯২",
    # "জন্ম - ১৯৯২",
    # "জন্মসাল 1792",

    # "আমার জন্ম সাল ১৯৯২",
    # "তার জন্ম ১৯৯২",
    # "জন্ম সাল ১৯৯২ সালে",
    # "সে জন্ম ১৯৯২ সালে",
    # "জন্মসাল ১৯৯২",
    # "জন্ম: ১৯৯২",
    # "জন্ম - ১৯৯২",
    # "তার birth date ১৯৯২",
    # "তার birth year ১৯৯২ সালে",
    # "His birth year 1992",
    # "born in 1995",
    # "১৯৯০ সালে জন্ম",
    
    # # Should NOT extract (no birth context)
    # "i am saiful 1400",
    # "মোট টাকা ১৯৯৫",
    # "রুম নম্বর 16021",
    # "ফোন: 16021",
    # "ফোন নম্বর: 16021",
    # "বয়স 1995",
    # "সাল 2000",  # Just "year 2000" without birth context
    # "মো: আব্দুল করিম",
    # "মোঃ রহিম উদ্দিন",
    # "মো. সালাম",
    # "মোছা: ফাতেমা বেগম",
    # "মোসা. খাদিজা",
    # "ইঞ্জিঃ জাহিদ হাসান",
    # "এবিসি লিঃ কোম্পানি",
    # "এবিসি লি. কোম্পানি"
    # "ডাঃ করিম",
    # "মোট টাকা ১০০",  # Should NOT be replaced
    # "মোড় পার হয়ে",  # Should NOT be replaced
    # # Test examples where replacements should NOT occur
    # # "মো" as part of complete words
    # "মোট টাকা ১০০০",                    # মোট = total
    # "মোড় থেকে ডানে যান",                # মোড় = turn/corner
    # "মোটা চাল কিনবো",                   # মোটা = thick/coarse
    # "মোমবাতি জ্বালাও",                  # মোমবাতি = candle
    # "মোবাইল ফোন",                      # মোবাইল = mobile
    # "মোকাম করতে হবে",                  # মোকাম = stay/reside
    # "মোকাবেলা করা",                    # মোকাবেলা = confront
    # "মোহর দিতে হবে",                    # মোহর = dower/seal
    # "মোচড় দিয়ে খুলুন",                # মোচড় = twist
    
    # # "লি" as part of complete words
    # "লিখতে পারি",                      # লিখতে = to write
    # "লিচু খাবো",                       # লিচু = lychee
    # "লিফট এ উঠুন",                     # লিফট = elevator
    # "লিস্ট তৈরি করুন",                 # লিস্ট = list
    # "লিংক পাঠান",                      # লিংক = link
    # "লিভার এর সমস্যা",                  # লিভার = liver
    # "লিপস্টিক লাগান",                  # লিপস্টিক = lipstick
    
    # # "ড" as part of complete words
    # "ডাক দিয়ে ডাকো",                   # ডাক = call
    # "ডাল ভাত খাবো",                    # ডাল = lentils
    # "ডান দিকে যান",                    # ডান = right
    # "ডিম ভাজি",                        # ডিম = egg
    # "ডুবে গেছে",                       # ডুবে = drowned
    
    # # "প্র" as part of complete words (not প্রঃ)
    # "প্রথম দিন",                       # প্রথম = first
    # "প্রশ্ন করুন",                     # প্রশ্ন = question
    # "প্রায় শেষ",                      # প্রায় = almost
    
    # # "সি" as part of complete words (not সিঃ)
    # "সিদ্ধান্ত নিন",                   # সিদ্ধান্ত = decision
    # "সিনেমা দেখবো",                    # সিনেমা = movie
    # "সিম কার্ড",                      # সিম = SIM
    
    # # "জু" as part of complete words (not জুঃ)
    # "জুতা পরুন",                       # জুতা = shoes
    # "জুস খাবো",                        # জুস = juice
    
    # # "কো" as part of complete words (not কোঃ)
    # "কোথায় যাবেন",                    # কোথায় = where
    # "কোন সমস্যা নেই",                  # কোন = which/any
    # "কোমর ব্যথা",                     # কোমর = waist
    
    # # Mixed sentences
    # "মোট ৫টি ডিম এবং ২ লিটার দুধ কিনুন",
    # "মোড় থেকে ডান দিকে মোবাইল এর দোকান",
    # "লিখতে লিখতে হাত ব্যথা",
    # "প্রতিদিন সিদ্ধ ডিম খান",
    # "আমাদের কল সেন্টার ১৬৯৮১"
    ]

    # texts = """

    # # ধন্যবাদ স্যার! আমাদের প্রচারমূলক ফ্লাইট অফারগুলো হলো... ১. ফ্লাইট নম্বর ইউবি ১০১, ঢাকা থেকে চট্টগ্রাম, সকাল ১০:০০ টায়। ভাড়া মাত্র ৩,৫০০ টাকা। ২. ফ্লাইট নম্বর ইউবি ২০২, ঢাকা থেকে সিলেট, দুপুর ১:০০ টায়। ভাড়া মাত্র Meeting 12:30:45 টায় and lunch 1:00 টা, break at 3:00"

    # """
    texts = [
        # "১৫-১১-১৯৯০",
        # "১৫ই নভেম্বর, ১৯৯০",
        # "জানুয়ারি ১৫, ১৯৯৫ বা March 10, 1988",
        # "২০০০সালের ১লা জানুয়ারি",
        # "১৯৯৫ সালের ১৫ই আগস্ট",
        # "১৯৯০ সালের ৩১শে ডিসেম্বর",
        # "১৯৮৫ সালের ৫মে",
        # "১৯৭০ সালের ২০শে জুন",
        # "১৫ আগস্ট ১৯৯৫",
        # "৩১ ডিসেম্বর ১৯৯০",
        # "৫মে ১৯৮৫",
        # "২০শে জুন ১৯৭০",
        # "অক্টোবর ৫, ২০০০",
        # "ডিসেম্বর ৩১, ১৯৯০",
        # "মে ৫, ১৯৮৫",
        # "জুন ২০, ১৯৭০",
        # "মার্চ ১০, ১৯৮৮",
        # "জানুয়ারি ১৫, ১৯৯৫"
        # "অক্টোবর ৫, ২০০০",
        # "জানুয়ারি ১৫, ১৯৯৫",
        # "৫মে ১৯৮৫",
        # 'ধন্যবাদ, বুঝতে না পারার জন্য জানিয়েছেন। আমি আবার সহজভাবে বলছি। আমি জানতে চাই, আপনার জন্ম তারিখ (Date of Birth) কী? দয়া করে মাস, দিন, এবং সাল—এইভাবে বলবেন। উদাহরণ: - "জানুয়ারি ১৫, ১৯৯৫" - "মার্চ ১০, ১৯৮৮" - "অক্টোবর ৫, ২০০০" আপনার জন্ম তারিখটি মাস, দিন, এবং সালসহ বলুন, দয়া করে। যদি বাংলায় বলেন, সেটিও ঠিক আছে—আমি নিশ্চিত করে নেব।',
        # "ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # "Phone numbers: ০১৭১৩ ৭২৭ ৩২৪ ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # "Mixed separators: ০১৭১৩ -৭২৭- ৩২৪ ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # "Multiple numbers: ৫৫১০ ৫৫ ৫৫১০ ৫৫১০ ৫৫ ৫৫১০ ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # "Single number: ৫৫১০ ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # "English: 123 456 789 ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # "English with hyphen: 123-456-789 ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # "Mixed: 123 -456- 789 ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # "Two numbers only: ১২৩ ৪৫৬ ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # "Four numbers: ১০০ ২০০ ৩০০ ৪০০ ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০",
        # 'ধন্যবাদ, নিশ্চিত করার জন্য। আপনার ঠিকানা আমি নোট করেছি: ১২৯৩, রোড ১৮, এভিনিউ ২, মিরপুর ৩, পল্লবী, ঢাকা এখন পরবর্তী ধাপে যাচ্ছি। এবার, আপনার জন্ম তারিখটি (Date of Birth) জানতে চাই। দয়া করে মাস-দিন-সাল (Month-Day-Year) ফরম্যাটে বলুন। উদাহরণ: "জানুয়ারি ১৫, ১৯৯৫" বা "March 10, 1988" আপনার জন্ম তারিখটি বলুন, দয়া করে।'
        # "নাম আর শেষ ৪ সংখ্যা ৪৫৬৭। ওটিপি 938221।",
        # "ভোটার আইডি ৪৫৬৭ আমি নোট করেছি",
        # "জাতীয় পরিচয়পত্র ৪৫৬৭ আমি নোট করেছি",
        # "ড্রাইভিং লাইসেন্স ৪৫৬৭",
        # "সিভিভি (CVV): 123",
        # "ওটিপি (OTP): 123456",
        # "রেফারেন্স আইডি 12345"
        
        # "আপনি বলেছেন: ০১৬৭৩ [পজ] ১ ১ ০ [পজ] ৭ ২ ০ তাহলে আপনার পুরো নম্বরটি হচ্ছে"
        # "এই প্রক্রিয়াটি আনুমানিক ১০-১৫ মিনিট সময় নিতে পারে।"
        # "The numbers are 10 নন-ক্যাডার 20.5  30, and 40.75. সুপারিশ ২০৩০.৩০ 12 23 45",
        # "তার পাসপোর্ট নম্বর P87654321 ছিল।, 1995-1969 and phone number 01773-550379"
        # "২০শে জুন ১৯৭০",
        # "অক্টোবর ৫, ১৯৯০",
        # "জানুয়ারি ১৫, ১৯৯৫"
    #     "বাড়ি নম্বর: ১২৯৩ - রাস্তা নম্বর: ১৮ - এভিনিউ: ২",
    #     "বাড়ি নম্বর: 12345 - রাস্তা নম্বর: 18 - এভিনিউ: 3",
    #     "ধন্যবাদ। তাহলে আপনার জন্ম তারিখ হচ্ছে ১৫ই নভেম্বর, ১৯৯০ —ঠিক আছে?",
    "আমাকে ১৯৯০ টাকা দেয় এন্ড তুমি ১২৯৩ টাকা নিও এন্ড 104201 টাকা 122 "
    ]

    text_list = texts

    config = {
        "passport": True,
        "driving_license": True,
        "nid": True,
        "number": True,
        "date": True,
        "puntuation": True,
        "whitespace": True,
    }

    start_time = time.time()
    for text in text_list:
        print("input : ", text)
        text = text.strip()
        text = nrml.text_normalizer(text,  all_operation=True)
        # text = nrml.driving_license_norlization(i)
        print("output : ", text)
        print("=" * 2)
        print("Time taken: ", time.time() - start_time)
        # print(nrml.text_diff(i, text))
        # # print()
        # print("+" * 40)

    # n = "জিরো ওয়ান ডাবল সেভেন থ্রি ডাবল ফাইভ নাইন থ্রি সেভেন নাইন"
    # # n = "আমাকে এক লক্ষ দুই হাজার এক টাকা দেয় এন্ড তুমি বিশ হাজার টাকা নিও এন্ড এক লক্ষ চার হাজার দুইশ এক টাকা এক ডবল দুই"

    # number_string = nrml.word2number(n)
    # print(number_string)
